package fr.itsonus.bousoleplussbackend.infrastructure.postgres;

import fr.itsonus.bousoleplussbackend.domain.auth.model.RefreshToken;
import fr.itsonus.bousoleplussbackend.domain.auth.model.User;
import fr.itsonus.bousoleplussbackend.domain.auth.spi.RefreshTokenCacheRepository;
import fr.itsonus.bousoleplussbackend.infrastructure.postgres.models.PostgresRefreshTokenDto;
import fr.itsonus.bousoleplussbackend.infrastructure.postgres.models.PostgresUserDto;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.Optional;

@Service
@AllArgsConstructor
public class RefreshTokenCacheProxyRepository implements RefreshTokenCacheRepository {

    private RefreshTokenCachePostgresRepository refreshTokenRepository;

    @Override
    public Optional<RefreshToken> findByToken(String token) {
        return refreshTokenRepository.findByToken(token).map(PostgresRefreshTokenDto::toRefreshToken);
    }

    @Override
    public Optional<RefreshToken> findByUser(User user) {
        return refreshTokenRepository.findByUser(new PostgresUserDto(user)).map(PostgresRefreshTokenDto::toRefreshToken);
    }

    @Override
    public void deleteByUserId(long userId) {
        refreshTokenRepository.deleteByUserId(userId);
    }

    @Override
    public RefreshToken save(RefreshToken refreshToken) {
        User user = refreshToken.getUser();
        var userDto = new PostgresUserDto(user);
        var refreshTokenDto = new PostgresRefreshTokenDto(refreshToken);
        refreshTokenDto.setUser(userDto);
        return refreshTokenRepository.save(refreshTokenDto).toRefreshToken();
    }

    @Override
    public void delete(RefreshToken refreshToken) {
        refreshTokenRepository.delete(new PostgresRefreshTokenDto(refreshToken));
    }
}
