package fr.itsonus.bousoleplussbackend.infrastructure.postgres;

import fr.itsonus.bousoleplussbackend.domain.auth.model.User;
import fr.itsonus.bousoleplussbackend.domain.auth.spi.UserCacheRepository;
import fr.itsonus.bousoleplussbackend.infrastructure.postgres.models.PostgresUserDto;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.Optional;

@Service
@AllArgsConstructor
public class UserCacheProxyRepository implements UserCacheRepository {

    private final UserCachePostgresRepository userRepository;

    @Override
    public Optional<User> findByEmail(String email) {
        return userRepository.findByEmail(email)
                .map(PostgresUserDto::toUser);
    }

    @Override
    public User save(User user) {
        var postgresUserDto = new PostgresUserDto(user);
        return userRepository.save(postgresUserDto).toUser();
    }

    @Override
    public Boolean existsByEmail(String email) {
        return userRepository.existsByEmail(email);
    }

    @Override
    public Optional<User> findById(Long id) {
        return userRepository.findById(id)
                .map(PostgresUserDto::toUser);
    }
}
